/*_############################################################################
  _## 
  _##  SNMP4J-AgentJMX - JMXScalarSupport.java  
  _## 
  _##  Copyright (C) 2006-2009  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.agent.mo.jmx;

import org.snmp4j.smi.OID;
import org.snmp4j.smi.Variable;

/**
 * The <code>JMXScalarSupport</code> provides the interface between SNMP values
 * and MBean based instrumentation. A <code>JMXScalarSupport</code> instance
 * usually supports more than one scalar object.
 *
 * @author Frank Fock
 * @version 1.0
 */
public interface JMXScalarSupport {

  /**
   * Gets the actual value for the specified object instance and type.
   * @param scalarInstanceOID
   *    the instance OID of the target object.
   * @param value
   *    the instance to hold the return value.
   * @return
   *    zero on success or a SNMP error status value if fetching the value
   *    fails.
   */
  int getScalarValue(OID scalarInstanceOID, Variable value);

  /**
   * Sets the value of the specified object instance and type.
   * @param scalarInstanceOID
   *    the instance OID of the target object.
   * @param value
   *    the instance's new value.
   * @return
   *    zero on success or a SNMP error status value if setting the value
   *    fails.
   */
  int setScalarValue(OID scalarInstanceOID, Variable value);

  /**
   * Checks the value of the specified object instance and type.
   * @param scalarInstanceOID
   *    the instance OID of the target object.
   * @param value
   *    the instance's new value.
   * @return
   *    zero on success or a SNMP error status value if setting the value
   *    fails.
   */
  int checkScalarValue(OID scalarInstanceOID, Variable value);
}
