/*_############################################################################
  _## 
  _##  SNMP4J-AgentJMX - CombinedTypedAttribute.java  
  _## 
  _##  Copyright (C) 2006-2009  Frank Fock (SNMP4J.org)
  _##  
  _##  This program is free software; you can redistribute it and/or modify
  _##  it under the terms of the GNU General Public License version 2 as 
  _##  published by the Free Software Foundation.
  _##
  _##  This program is distributed in the hope that it will be useful,
  _##  but WITHOUT ANY WARRANTY; without even the implied warranty of
  _##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  _##  GNU General Public License for more details.
  _##
  _##  You should have received a copy of the GNU General Public License
  _##  along with this program; if not, write to the Free Software
  _##  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
  _##  MA  02110-1301  USA
  _##  
  _##########################################################################*/
package org.snmp4j.agent.mo.jmx.types;

import javax.management.*;

public class CombinedTypedAttribute extends TypedAttribute {

  protected TypedAttribute[] combinedAttributes;

  public CombinedTypedAttribute(String name, Class type,
                                TypedAttribute[] combinedAttributes) {
    super(name, type);
    this.combinedAttributes = combinedAttributes;
  }

  public TypedAttribute[] getAttributes() {
    return combinedAttributes;
  }

  public Object transformFromNative(Object nativeValue, ObjectName objectName) {
    Object[] values = (Object[])nativeValue;
    for (int i=0; ((i<values.length) &&
                   (i<combinedAttributes.length)); i++) {
      if (values[i] != null) {
        return values[i];
      }
    }
    return null;
  }

  public Object transformToNative(Object transformedValue,
                                  Object oldNativeValue, ObjectName objectName) {
    Object[] values = (Object[])oldNativeValue;
    Object[] nativeValues = new Object[values.length];
    for (int i=0; ((i<values.length) &&
                   (i<combinedAttributes.length)); i++) {
      if (values[i] != null) {
        nativeValues[i] = transformedValue;
      }
    }
    return nativeValues;
  }

  public boolean isNativeValueAlwaysNeeded() {
    return true;
  }

}
